Installation
============

.. currentmodule:: deeplake

Deep Lake can be installed with pip ::

    pip install deeplake

Deep Lake has the following extras that you can choose to install according to your needs.

.. csv-table:: Installation commands
    :file: _static/csv/installation.csv
    :header-rows: 1
